@@ -3,6 +3,7 @@
 
 import importlib
 import os
+import warnings
 from collections import namedtuple
 from copy import deepcopy
 from html import escape
@@ -32,7 +33,13 @@ from ... import (
     extract,
 )
 
-from ...data.base import dict_to_dataset, generate_dims_coords, infer_stan_dtypes, make_attrs
+from ...data.base import (
+    dict_to_dataset,
+    generate_dims_coords,
+    infer_stan_dtypes,
+    make_attrs,
+    numpy_to_data_array,
+)
 from ...data.datasets import LOCAL_DATASETS, REMOTE_DATASETS, RemoteFileMetadata
 from ..helpers import (  # pylint: disable=unused-import
     chains,
@@ -44,6 +51,10 @@ from ..helpers import (  # pylint: disable=unused-import
     models,
 )
 
+# Check if dm-tree is installed
+dm_tree_installed = importlib.util.find_spec("tree") is not None  # pylint: disable=invalid-name
+skip_tests = (not dm_tree_installed) and ("ARVIZ_REQUIRE_ALL_DEPS" not in os.environ)
+
 
 @pytest.fixture(autouse=True)
 def no_remote_data(monkeypatch, tmpdir):
@@ -227,6 +238,17 @@ def test_dims_coords_skip_event_dims(shape):
     assert "z" not in coords
 
 
+@pytest.mark.parametrize("dims", [None, ["chain", "draw"], ["chain", "draw", None]])
+def test_numpy_to_data_array_with_dims(dims):
+    da = numpy_to_data_array(
+        np.empty((4, 500, 7)),
+        var_name="a",
+        dims=dims,
+        default_dims=["chain", "draw"],
+    )
+    assert list(da.dims) == ["chain", "draw", "a_dim_0"]
+
+
 def test_make_attrs():
     extra_attrs = {"key": "Value"}
     attrs = make_attrs(attrs=extra_attrs)
@@ -895,6 +917,11 @@ class TestInferenceData:  # pylint: disable=too-many-public-methods
         assert escape(repr(idata)) in html
         xr.set_options(display_style=display_style)
 
+    def test_setitem(self, data_random):
+        data_random["new_group"] = data_random.posterior
+        assert "new_group" in data_random.groups()
+        assert hasattr(data_random, "new_group")
+
     def test_add_groups(self, data_random):
         data = np.random.normal(size=(4, 500, 8))
         idata = data_random
@@ -912,7 +939,7 @@ class TestInferenceData:  # pylint: disable=too-many-public-methods
         data = np.random.normal(size=(4, 500, 8))
         idata = data_random
         with pytest.warns(UserWarning, match="The group.+not defined in the InferenceData scheme"):
-            idata.add_groups({"new_group": idata.posterior})
+            idata.add_groups({"new_group": idata.posterior}, warn_on_custom_groups=True)
         with pytest.warns(UserWarning, match="the default dims.+will be added automatically"):
             idata.add_groups(constant_data={"a": data[..., 0], "b": data})
         assert idata.new_group.equals(idata.posterior)
@@ -953,8 +980,8 @@ class TestInferenceData:  # pylint: disable=too-many-public-methods
         with pytest.raises(ValueError, match="join must be either"):
             idata.extend(idata2, join="outer")
         idata2.add_groups(new_group=idata2.prior)
-        with pytest.warns(UserWarning):
-            idata.extend(idata2)
+        with pytest.warns(UserWarning, match="new_group"):
+            idata.extend(idata2, warn_on_custom_groups=True)
 
 
 class TestNumpyToDataArray:
@@ -1076,6 +1103,7 @@ def test_dict_to_dataset():
     assert set(dataset.b.coords) == {"chain", "draw", "c"}
 
 
+@pytest.mark.skipif(skip_tests, reason="test requires dm-tree which is not installed")
 def test_nested_dict_to_dataset():
     datadict = {
         "top": {"a": np.random.randn(100), "b": np.random.randn(1, 100, 10)},
@@ -1146,11 +1174,17 @@ def test_bad_inference_data():
         InferenceData(posterior=[1, 2, 3])
 
 
-def test_inference_data_other_groups():
+@pytest.mark.parametrize("warn", [True, False])
+def test_inference_data_other_groups(warn):
     datadict = {"a": np.random.randn(100), "b": np.random.randn(1, 100, 10)}
     dataset = convert_to_dataset(datadict, coords={"c": np.arange(10)}, dims={"b": ["c"]})
-    with pytest.warns(UserWarning, match="not.+in.+InferenceData scheme"):
-        idata = InferenceData(other_group=dataset)
+    if warn:
+        with pytest.warns(UserWarning, match="not.+in.+InferenceData scheme"):
+            idata = InferenceData(other_group=dataset, warn_on_custom_groups=True)
+    else:
+        with warnings.catch_warnings():
+            warnings.simplefilter("error")
+            idata = InferenceData(other_group=dataset, warn_on_custom_groups=False)
     fails = check_multiple_attrs({"other_group": ["a", "b"]}, idata)
     assert not fails
 
